docker

package
v0.1.58 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 6, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ImageExists

func ImageExists(image string) bool

ImageExists checks to see if a docker image exists in the local registry takes one argument, the image name: docker.ImageExists("NameOfImage")

func Pull

func Pull(image string) bool

Types

type ImageObj added in v0.1.56

type ImageObj struct {
	Name  string
	Flags string
}

func Image added in v0.1.56

func Image(name string) *ImageObj

func (*ImageObj) Interactive added in v0.1.56

func (image *ImageObj) Interactive() *ImageObj

func (*ImageObj) Mount added in v0.1.57

func (image *ImageObj) Mount(source, dest string) *ImageObj

func (*ImageObj) Run added in v0.1.56

func (image *ImageObj) Run(formatString string, args ...interface{}) string

Jump to