Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ImageExists ¶
ImageExists checks to see if a docker image exists in the local registry takes one argument, the image name: docker.ImageExists("NameOfImage")
Types ¶
Click to show internal directories.
Click to hide internal directories.